@@ -79,29 +79,29 @@ myTarGetStats <-
       
       # daily stat
       if ( stat_type == "day" ) {
-          # start cycle by each element, object
-          for ( i in 1:length(temp_all_data$items) ) {
+        # start cycle by each element, object
+        for ( i in 1:length(temp_all_data$items) ) {
+          
+          # get id of current obj
+          id <- temp_all_data$items[[i]]$id
+          
+          # cycle by each rows in obj
+          for( r in 1:length(temp_all_data$items[[2]]$rows) ) {
+            # get date
+            date <- temp_all_data$items[[i]]$rows[[r]]$date
+            # get metrics list
+            m <- names(temp_all_data$items[[i]]$rows[[r]])[names(temp_all_data$items[[i]]$rows[[r]]) != "date"]
             
-            # get id of current obj
-            id <- temp_all_data$items[[i]]$id
-            
-            # cycle by each rows in obj
-            for( r in 1:length(temp_all_data$items[[2]]$rows) ) {
-              # get date
-              date <- temp_all_data$items[[i]]$rows[[r]]$date
-              # get metrics list
-              m <- names(temp_all_data$items[[i]]$rows[[r]])[names(temp_all_data$items[[i]]$rows[[r]]) != "date"]
+            for ( cur_metric in m ) {
+              assign(cur_metric, 
+                     bind_rows(get(cur_metric), 
+                               bind_cols(c(id = id, 
+                                           date = date, 
+                                           temp_all_data$items[[i]]$rows[[r]][[cur_metric]] ))))
               
-              for ( cur_metric in m ) {
-                assign(cur_metric, 
-                       bind_rows(get(cur_metric), 
-                                 bind_cols(c(id = id, 
-                                             date = date, 
-                                             temp_all_data$items[[i]]$rows[[r]][[cur_metric]] ))))
-                
-              }
             }
-          } 
+          }
+        } 
       } else {
         
         # summary stat
@@ -125,21 +125,21 @@ myTarGetStats <-
           }
         }
       }
-        #Progresbar step
-        if ( nparts > 1 ) {
-          pb_step <- pb_step + 1
-          utils::setTxtProgressBar(pb, pb_step)}
-      }    
-      
-      if ( exists("pb") ) {
-        close(pb)
-      }
-      
       #Progresbar step
       if ( nparts > 1 ) {
         pb_step <- pb_step + 1
         utils::setTxtProgressBar(pb, pb_step)}
-        
+    }    
+    
+    if ( exists("pb") ) {
+      close(pb)
+    }
+    
+    #Progresbar step
+    if ( nparts > 1 ) {
+      pb_step <- pb_step + 1
+      utils::setTxtProgressBar(pb, pb_step)}
+    
     
     if ( exists("pb") ) {
       close(pb)
@@ -152,16 +152,16 @@ myTarGetStats <-
     assign("result", get(m[1])) 
     
     for ( j in m ) {
-      
+
       if ( j == m[1] ) next
       
       if ( stat_type == "day" ) {
-      
+        
         if ( j == "viral") {
           assign(j, setNames(get(j),  c("id", "date", paste0( "viral_", names(get(j))[ !names(get(j)) %in% c("id", "date") ] ))))
-        } else {
-          assign(j, setNames(get(j),  c("id", paste0( "viral_", names(get(j))[ !names(get(j)) %in% "id" ] ))))
-        }
+        } 
+      } else if ( j == "viral") {
+        assign(j, setNames(get(j),  c("id", paste0( "viral_", names(get(j))[ !names(get(j)) %in% "id" ] ))))
       }
       
       # join to result
@@ -177,4 +177,4 @@ myTarGetStats <-
     message("Total time: ", as.numeric(difftime(stop_time, start_time), units = "secs"), " sec.")
     # return total result
     return(result)
-}
\ No newline at end of file
+  }
